__author__ = 'Xiaoou WANG'


def min(a, b):
    if a <= b:
        return a
    else:
        return b